@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -35,12 +35,12 @@ $*/
 
 #define MLK_FONT_FREETYPE_DEFINE
 
-#include "mlk.h"
-#include "mlk_font.h"
-#include "mlk_fontinfo.h"
-#include "mlk_font_freetype.h"
-#include "mlk_fontconfig.h"
-#include "mlk_str.h"
+#include <mlk.h>
+#include <mlk_font.h>
+#include <mlk_fontinfo.h>
+#include <mlk_font_freetype.h>
+#include <mlk_fontconfig.h>
+#include <mlk_str.h>
 
 
 
