@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -23,10 +23,10 @@ $*/
 
 #include <fontconfig/fontconfig.h>
 
-#include "mlk.h"
-#include "mlk_fontconfig.h"
-#include "mlk_fontinfo.h"
-#include "mlk_str.h"
+#include <mlk.h>
+#include <mlk_fontconfig.h>
+#include <mlk_fontinfo.h>
+#include <mlk_str.h>
 
 
 #define _PUT_DEBUG 0
