@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -21,12 +21,12 @@ $*/
  * mAccelerator
  *****************************************/
 
-#include "mlk_gui.h"
-#include "mlk_accelerator.h"
-#include "mlk_list.h"
-#include "mlk_event.h"
-#include "mlk_str.h"
-#include "mlk_key.h"
+#include <mlk_gui.h>
+#include <mlk_accelerator.h>
+#include <mlk_list.h>
+#include <mlk_event.h>
+#include <mlk_str.h>
+#include <mlk_key.h>
 
 #include "mlk_pv_gui.h"
 
