@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -24,10 +24,10 @@ $*/
 /* リストは、常にタイマーの起動時間が早い順に並ぶ。 */
 
 
-#include "mlk_gui.h"
-#include "mlk_nanotime.h"
-#include "mlk_list.h"
-#include "mlk_event.h"
+#include <mlk_gui.h>
+#include <mlk_nanotime.h>
+#include <mlk_list.h>
+#include <mlk_event.h>
 
 #include "mlk_pv_gui.h"
 
