@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -25,8 +25,8 @@ $*/
 
 #include <string.h>
 
-#include "mlk_gui.h"
-#include "mlk_list.h"
+#include <mlk_gui.h>
+#include <mlk_list.h>
 
 #include "mlk_pv_gui.h"
 #include "mlk_pv_mimelist.h"
