@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -21,9 +21,9 @@ $*/
  * GIF 保存
  *****************************************/
 
-#include "mlk.h"
-#include "mlk_saveimage.h"
-#include "mlk_gifenc.h"
+#include <mlk.h>
+#include <mlk_saveimage.h>
+#include <mlk_gifenc.h>
 
 
 //---------------
