@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -24,8 +24,8 @@ $*/
 #include <stdio.h>
 #include <webp/encode.h>
 
-#include "mlk.h"
-#include "mlk_saveimage.h"
+#include <mlk.h>
+#include <mlk_saveimage.h>
 
 
 //---------------
