@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -23,9 +23,9 @@ $*/
 
 #include <string.h>
 
-#include "mlk.h"
-#include "mlk_buf.h"
-#include "mlk_unicode.h"
+#include <mlk.h>
+#include <mlk_buf.h>
+#include <mlk_unicode.h>
 
 
 
