@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -23,11 +23,11 @@ $*/
 
 #include <string.h>
 
-#include "mlk.h"
-#include "mlk_filelist.h"
-#include "mlk_dir.h"
-#include "mlk_list.h"
-#include "mlk_string.h"
+#include <mlk.h>
+#include <mlk_filelist.h>
+#include <mlk_dir.h>
+#include <mlk_list.h>
+#include <mlk_string.h>
 
 
 
