@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -21,9 +21,9 @@ $*/
  * 乱数生成
  *****************************************/
 
-#include "mlk.h"
-#include "mlk_rand.h"
-#include "mlk_simd.h"
+#include <mlk.h>
+#include <mlk_rand.h>
+#include <mlk_simd.h>
 
 
 //===========================
