@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -23,28 +23,28 @@ $*/
 
 #include <string.h>
 
-#include "mlk_gui.h"
-#include "mlk_widget_def.h"
-#include "mlk_widget.h"
-#include "mlk_window.h"
-#include "mlk_sysdlg.h"
-#include "mlk_filedialog.h"
-#include "mlk_event.h"
-#include "mlk_menu.h"
+#include <mlk_gui.h>
+#include <mlk_widget_def.h>
+#include <mlk_widget.h>
+#include <mlk_window.h>
+#include <mlk_sysdlg.h>
+#include <mlk_filedialog.h>
+#include <mlk_event.h>
+#include <mlk_menu.h>
 
-#include "mlk_label.h"
-#include "mlk_button.h"
-#include "mlk_lineedit.h"
-#include "mlk_combobox.h"
-#include "mlk_imgbutton.h"
-#include "mlk_arrowbutton.h"
-#include "mlk_filelistview.h"
+#include <mlk_label.h>
+#include <mlk_button.h>
+#include <mlk_lineedit.h>
+#include <mlk_combobox.h>
+#include <mlk_imgbutton.h>
+#include <mlk_arrowbutton.h>
+#include <mlk_filelistview.h>
 
-#include "mlk_str.h"
-#include "mlk_file.h"
-#include "mlk_string.h"
+#include <mlk_str.h>
+#include <mlk_file.h>
+#include <mlk_string.h>
 
-#include "mlk_pv_gui.h"
+#include <mlk_pv_gui.h>
 
 
 /* 翻訳グループは、システムにセットされるが、ダイアログ終了時に元のグループに戻る。 */
