@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -22,21 +22,21 @@ $*/
  * メニューポップアップウィンドウ
  *****************************************/
 
-#include "mlk_gui.h"
-#include "mlk_widget_def.h"
-#include "mlk_widget.h"
-#include "mlk_window.h"
-#include "mlk_menubar.h"
-#include "mlk_event.h"
-#include "mlk_menu.h"
-#include "mlk_guicol.h"
-#include "mlk_key.h"
-#include "mlk_pixbuf.h"
-#include "mlk_font.h"
+#include <mlk_gui.h>
+#include <mlk_widget_def.h>
+#include <mlk_widget.h>
+#include <mlk_window.h>
+#include <mlk_menubar.h>
+#include <mlk_event.h>
+#include <mlk_menu.h>
+#include <mlk_guicol.h>
+#include <mlk_key.h>
+#include <mlk_pixbuf.h>
+#include <mlk_font.h>
 
-#include "mlk_pv_gui.h"
-#include "mlk_pv_window.h"
-#include "mlk_pv_menu.h"
+#include <mlk_pv_gui.h>
+#include <mlk_pv_window.h>
+#include <mlk_pv_menu.h>
 
 
 //------------------------
