@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -21,18 +21,18 @@ $*/
  * mWindow 内部関数
  *****************************************/
 
-#include "mlk_gui.h"
-#include "mlk_widget_def.h"
-#include "mlk_widget.h"
-#include "mlk_window.h"
-#include "mlk_event.h"
-#include "mlk_pixbuf.h"
-#include "mlk_rectbox.h"
-#include "mlk_window_deco.h"
+#include <mlk_gui.h>
+#include <mlk_widget_def.h>
+#include <mlk_widget.h>
+#include <mlk_window.h>
+#include <mlk_event.h>
+#include <mlk_pixbuf.h>
+#include <mlk_rectbox.h>
+#include <mlk_window_deco.h>
 
-#include "mlk_pv_gui.h"
-#include "mlk_pv_widget.h"
-#include "mlk_pv_window.h"
+#include <mlk_pv_gui.h>
+#include <mlk_pv_widget.h>
+#include <mlk_pv_window.h>
 
 
 /** mWindow データ作成
