@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -21,10 +21,10 @@ $*/
  * ヘルプ
  ***************************/
 
-#include "mlk_gui.h"
-#include "mlk_translation.h"
-#include "mlk_sysdlg.h"
-#include "mlk_str.h"
+#include <mlk_gui.h>
+#include <mlk_translation.h>
+#include <mlk_sysdlg.h>
+#include <mlk_str.h>
 
 #include "apphelp.h"
 
