@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -21,10 +21,10 @@ $*/
  * アプリ用リソース管理
  ***********************************/
 
-#include "mlk_gui.h"
-#include "mlk_imagelist.h"
-#include "mlk_loadimage.h"
-#include "mlk_str.h"
+#include <mlk_gui.h>
+#include <mlk_imagelist.h>
+#include <mlk_loadimage.h>
+#include <mlk_str.h>
 
 #include "appresource.h"
 
