@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -23,12 +23,12 @@ $*/
 
 #include <stdio.h>
 
-#include "mlk_gui.h"
-#include "mlk_widget_def.h"
-#include "mlk_popup_progress.h"
-#include "mlk_zlib.h"
-#include "mlk_stdio.h"
-#include "mlk_util.h"
+#include <mlk_gui.h>
+#include <mlk_widget_def.h>
+#include <mlk_popup_progress.h>
+#include <mlk_zlib.h>
+#include <mlk_stdio.h>
+#include <mlk_util.h>
 
 #include "def_draw.h"
 
