@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -23,11 +23,11 @@ $*/
 
 #include <string.h>
 
-#include "mlk_gui.h"
-#include "mlk_widget_def.h"
-#include "mlk_popup_progress.h"
-#include "mlk_loadimage.h"
-#include "mlk_file.h"
+#include <mlk_gui.h>
+#include <mlk_widget_def.h>
+#include <mlk_popup_progress.h>
+#include <mlk_loadimage.h>
+#include <mlk_file.h>
 
 #include "def_macro.h"
 #include "def_config.h"
