@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -28,8 +28,8 @@ $*/
 #include <stdlib.h>	//abs
 #include <math.h>
 
-#include "mlk_gui.h"
-#include "mlk_rectbox.h"
+#include <mlk_gui.h>
+#include <mlk_rectbox.h>
 
 #include "def_draw.h"
 #include "def_tool_option.h"
