@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -23,7 +23,7 @@ $*/
 
 #include <math.h>
 
-#include "mlk.h"
+#include <mlk.h>
 
 #include "def_filterdraw.h"
 
