@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -24,8 +24,8 @@ $*/
 #include <string.h>
 #include <math.h>
 
-#include "mlk.h"
-#include "mlk_rand.h"
+#include <mlk.h>
+#include <mlk_rand.h>
 
 
 //------------------
