@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -23,10 +23,10 @@ $*/
 
 #include <string.h>
 
-#include "mlk.h"
-#include "mlk_pixbuf.h"
-#include "mlk_simd.h"
-#include "mlk_util.h"
+#include <mlk.h>
+#include <mlk_pixbuf.h>
+#include <mlk_simd.h>
+#include <mlk_util.h>
 
 #include "imagecanvas.h"
 #include "colorvalue.h"
