@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -24,9 +24,9 @@ $*/
 
 #include <string.h>
 
-#include "mlk.h"
-#include "mlk_str.h"
-#include "mlk_pixbuf.h"
+#include <mlk.h>
+#include <mlk_str.h>
+#include <mlk_pixbuf.h>
 
 #include "imagematerial.h"
 #include "image32.h"
