@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -25,11 +25,11 @@ $*/
 #include <math.h>
 #include <time.h>
 
-#include "mlk.h"
-#include "mlk_rectbox.h"
-#include "mlk_pixbuf.h"
-#include "mlk_rand.h"
-#include "mlk_simd.h"
+#include <mlk.h>
+#include <mlk_rectbox.h>
+#include <mlk_pixbuf.h>
+#include <mlk_rand.h>
+#include <mlk_simd.h>
 
 #include "def_tileimage.h"
 
