@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -29,12 +29,12 @@ $*/
 
 #define MLK_FONT_FREETYPE_DEFINE
 
-#include "mlk_gui.h"
-#include "mlk_list.h"
-#include "mlk_font.h"
-#include "mlk_font_freetype.h"
-#include "mlk_opentype.h"
-#include "mlk_util.h"
+#include <mlk_gui.h>
+#include <mlk_list.h>
+#include <mlk_font.h>
+#include <mlk_font_freetype.h>
+#include <mlk_opentype.h>
+#include <mlk_util.h>
 
 #include "fontcache.h"
 
