@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -26,8 +26,8 @@ $*/
 #include <stdio.h>	//FILE*
 #include <string.h>
 
-#include "mlk.h"
-#include "mlk_undo.h"
+#include <mlk.h>
+#include <mlk_undo.h>
 
 #include "def_draw.h"
 
