@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -23,19 +23,19 @@ $*/
 
 #include <string.h>
 
-#include "mlk_gui.h"
-#include "mlk_widget_def.h"
-#include "mlk_widget.h"
-#include "mlk_window.h"
-#include "mlk_label.h"
-#include "mlk_listview.h"
-#include "mlk_containerview.h"
-#include "mlk_pager.h"
-#include "mlk_event.h"
-#include "mlk_columnitem.h"
-#include "mlk_str.h"
-#include "mlk_sysdlg.h"
-#include "mlk_file.h"
+#include <mlk_gui.h>
+#include <mlk_widget_def.h>
+#include <mlk_widget.h>
+#include <mlk_window.h>
+#include <mlk_label.h>
+#include <mlk_listview.h>
+#include <mlk_containerview.h>
+#include <mlk_pager.h>
+#include <mlk_event.h>
+#include <mlk_columnitem.h>
+#include <mlk_str.h>
+#include <mlk_sysdlg.h>
+#include <mlk_file.h>
 
 #include "def_config.h"
 #include "def_draw.h"
