@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -21,20 +21,20 @@ $*/
  * 環境設定のページ
  *****************************************/
 
-#include "mlk_gui.h"
-#include "mlk_widget_def.h"
-#include "mlk_widget.h"
-#include "mlk_pager.h"
-#include "mlk_groupbox.h"
-#include "mlk_label.h"
-#include "mlk_lineedit.h"
-#include "mlk_checkbutton.h"
-#include "mlk_colorbutton.h"
-#include "mlk_fontbutton.h"
-#include "mlk_combobox.h"
-#include "mlk_fileinput.h"
-#include "mlk_event.h"
-#include "mlk_str.h"
+#include <mlk_gui.h>
+#include <mlk_widget_def.h>
+#include <mlk_widget.h>
+#include <mlk_pager.h>
+#include <mlk_groupbox.h>
+#include <mlk_label.h>
+#include <mlk_lineedit.h>
+#include <mlk_checkbutton.h>
+#include <mlk_colorbutton.h>
+#include <mlk_fontbutton.h>
+#include <mlk_combobox.h>
+#include <mlk_fileinput.h>
+#include <mlk_event.h>
+#include <mlk_str.h>
 
 #include "def_config.h"
 
