@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -21,16 +21,16 @@ $*/
  * グラデーションリスト編集ダイアログ
  *****************************************/
 
-#include "mlk_gui.h"
-#include "mlk_widget_def.h"
-#include "mlk_widget.h"
-#include "mlk_window.h"
-#include "mlk_listview.h"
-#include "mlk_iconbar.h"
-#include "mlk_event.h"
-#include "mlk_columnitem.h"
-#include "mlk_pixbuf.h"
-#include "mlk_list.h"
+#include <mlk_gui.h>
+#include <mlk_widget_def.h>
+#include <mlk_widget.h>
+#include <mlk_window.h>
+#include <mlk_listview.h>
+#include <mlk_iconbar.h>
+#include <mlk_event.h>
+#include <mlk_columnitem.h>
+#include <mlk_pixbuf.h>
+#include <mlk_list.h>
 
 #include "def_draw.h"
 #include "def_tool_option.h"
