@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -21,21 +21,21 @@ $*/
  * レイヤ色選択ダイアログ
  *****************************************/
 
-#include "mlk_gui.h"
-#include "mlk_widget_def.h"
-#include "mlk_widget.h"
-#include "mlk_window.h"
-#include "mlk_label.h"
-#include "mlk_button.h"
-#include "mlk_checkbutton.h"
-#include "mlk_lineedit.h"
-#include "mlk_colorprev.h"
-#include "mlk_hsvpicker.h"
-#include "mlk_sliderbar.h"
-#include "mlk_event.h"
-#include "mlk_pixbuf.h"
-#include "mlk_guicol.h"
-#include "mlk_color.h"
+#include <mlk_gui.h>
+#include <mlk_widget_def.h>
+#include <mlk_widget.h>
+#include <mlk_window.h>
+#include <mlk_label.h>
+#include <mlk_button.h>
+#include <mlk_checkbutton.h>
+#include <mlk_lineedit.h>
+#include <mlk_colorprev.h>
+#include <mlk_hsvpicker.h>
+#include <mlk_sliderbar.h>
+#include <mlk_event.h>
+#include <mlk_pixbuf.h>
+#include <mlk_guicol.h>
+#include <mlk_color.h>
 
 #include "def_draw.h"
 #include "draw_main.h"
