@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -21,32 +21,32 @@ $*/
  * テキスト描画ダイアログ
  *************************************/
 
-#include "mlk_gui.h"
-#include "mlk_widget_def.h"
-#include "mlk_widget.h"
-#include "mlk_window.h"
-#include "mlk_groupbox.h"
-#include "mlk_label.h"
-#include "mlk_button.h"
-#include "mlk_checkbutton.h"
-#include "mlk_imgbutton.h"
-#include "mlk_arrowbutton.h"
-#include "mlk_lineedit.h"
-#include "mlk_multiedit.h"
-#include "mlk_combobox.h"
-#include "mlk_tab.h"
-#include "mlk_splitter.h"
-#include "mlk_containerview.h"
-#include "mlk_iconbar.h"
-#include "mlk_event.h"
-#include "mlk_imagelist.h"
-#include "mlk_fontlist.h"
-#include "mlk_columnitem.h"
-#include "mlk_sysdlg.h"
-#include "mlk_menu.h"
-#include "mlk_str.h"
-#include "mlk_key.h"
-#include "mlk_util.h"
+#include <mlk_gui.h>
+#include <mlk_widget_def.h>
+#include <mlk_widget.h>
+#include <mlk_window.h>
+#include <mlk_groupbox.h>
+#include <mlk_label.h>
+#include <mlk_button.h>
+#include <mlk_checkbutton.h>
+#include <mlk_imgbutton.h>
+#include <mlk_arrowbutton.h>
+#include <mlk_lineedit.h>
+#include <mlk_multiedit.h>
+#include <mlk_combobox.h>
+#include <mlk_tab.h>
+#include <mlk_splitter.h>
+#include <mlk_containerview.h>
+#include <mlk_iconbar.h>
+#include <mlk_event.h>
+#include <mlk_imagelist.h>
+#include <mlk_fontlist.h>
+#include <mlk_columnitem.h>
+#include <mlk_sysdlg.h>
+#include <mlk_menu.h>
+#include <mlk_str.h>
+#include <mlk_key.h>
+#include <mlk_util.h>
 
 #include "def_widget.h"
 #include "def_config.h"
