@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -21,14 +21,14 @@ $*/
  * [panel] キャンバスビュー
  *****************************************/
 
-#include "mlk_gui.h"
-#include "mlk_widget_def.h"
-#include "mlk_widget.h"
-#include "mlk_window.h"
-#include "mlk_panel.h"
-#include "mlk_iconbar.h"
-#include "mlk_event.h"
-#include "mlk_menu.h"
+#include <mlk_gui.h>
+#include <mlk_widget_def.h>
+#include <mlk_widget.h>
+#include <mlk_window.h>
+#include <mlk_panel.h>
+#include <mlk_iconbar.h>
+#include <mlk_event.h>
+#include <mlk_menu.h>
 
 #include "def_widget.h"
 #include "def_config.h"
