@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -27,18 +27,18 @@ $*/
 #include <stdio.h>
 #include <math.h>
 
-#include "mlk_gui.h"
-#include "mlk_widget_def.h"
-#include "mlk_widget.h"
-#include "mlk_window.h"
-#include "mlk_event.h"
-#include "mlk_pager.h"
-#include "mlk_label.h"
-#include "mlk_iconbar.h"
-#include "mlk_button.h"
-#include "mlk_checkbutton.h"
-#include "mlk_menu.h"
-#include "mlk_str.h"
+#include <mlk_gui.h>
+#include <mlk_widget_def.h>
+#include <mlk_widget.h>
+#include <mlk_window.h>
+#include <mlk_event.h>
+#include <mlk_pager.h>
+#include <mlk_label.h>
+#include <mlk_iconbar.h>
+#include <mlk_button.h>
+#include <mlk_checkbutton.h>
+#include <mlk_menu.h>
+#include <mlk_str.h>
 
 #include "def_draw.h"
 
