@@ -1,5 +1,5 @@
 /*$
- Copyright (C) 2013-2022 Azel.
+ Copyright (C) 2013-2023 Azel.
 
  This file is part of AzPainter.
 
@@ -23,13 +23,13 @@ $*/
 
 #include <stdio.h>
 
-#include "mlk_gui.h"
-#include "mlk_widget_def.h"
-#include "mlk_widget.h"
-#include "mlk_window.h"
-#include "mlk_menu.h"
-#include "mlk_sysdlg.h"
-#include "mlk_str.h"
+#include <mlk_gui.h>
+#include <mlk_widget_def.h>
+#include <mlk_widget.h>
+#include <mlk_window.h>
+#include <mlk_menu.h>
+#include <mlk_sysdlg.h>
+#include <mlk_str.h>
 
 #include "def_draw.h"
 #include "def_draw_toollist.h"
